@@ -1,6 +1,7 @@
 #!/bin/sh
 
 export LANG=C
+DEBDATE=$(date -u -d @$(dpkg-parsechangelog -S Timestamp) +"%b, %d %Y")
 
 projectname() {
   local project
@@ -13,7 +14,7 @@ projectname() {
 do_manpage() {
  local p
 cat <<EOF
-.TH IEM-PLUGIN-SUITE 1 "$(date -u -d @$(dpkg-parsechangelog -S Timestamp) +"%b, %d %Y")"
+.TH IEM-PLUGIN-SUITE 1 "${DEBDATE}"
 .SH NAME
 iem-plugin-suite \- Standalone application of the IEMPluginSuite
 .SH SYNOPSIS
@@ -42,20 +43,33 @@ for the Debian project (but may be used by others).
 EOF
 }
 
-rm -rf _man _bin
-mkdir -p _man _bin
+rm -rf _man _bin _desktop
+mkdir -p _man _bin _desktop
+
+
+cp resources/Standalone/IEMPluginSuiteSmall.png _desktop/iem-plugin.png
 
 for Standalone in "$@"; do
  test -x "${Standalone}" || continue
- standalone=iem-plugin-$(basename "${Standalone}" | tr A-Z a-z)
- cp "$Standalone" "_bin/${standalone}"
+ Name=$(basename "${Standalone}")
+ name=$(echo ${Name} | tr A-Z a-z)
+ standalone=iem-plugin-${name}
+ cp "${Standalone}" "_bin/${standalone}"
+ # generate a .desktop file for each standalone
+ sed \
+	-e "s|@Name@|${Name}|g" -e "s|@name@|${name}|g" \
+	debian/iem-plugin.desktop.in > "_desktop/${standalone}.desktop"
 done
 
+## generate the generic manpage for all plugins
+## (which lists all the available plugins)
 do_manpage $(for f in _bin/*; do test -e "${f}" && echo $f; done |  sort -u) > _man/iem-plugin-suite.1
 
+## copy the generic manpage as the specific manpage
 for x in _bin/*; do
  test -x "${x}" || continue
  cp _man/iem-plugin-suite.1 _man/$(basename "$x").1
 done
 
+## drop the generic manpage
 rm -f _man/iem-plugin-suite.1
